==> ideaIC-141.1192.2-sources.jar: com/intellij/ui/components/JBPanel.java <==
/*
 * Copyright 2000-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.ui.components;

import com.intellij.openapi.actionSystem.DataKey;
import com.intellij.openapi.actionSystem.DataSink;
import com.intellij.openapi.actionSystem.TypeSafeDataProvider;
import com.intellij.util.IconUtil;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import java.awt.*;

/**
 * @author Konstantin Bulenkov
 */
public class JBPanel extends JPanel implements TypeSafeDataProvider {
  @Nullable
  private Icon myBackgroundImage;
  @Nullable
  private Icon myCenterImage;

  public JBPanel(LayoutManager layout, boolean isDoubleBuffered) {
    super(layout, isDoubleBuffered);
  }

  public JBPanel(LayoutManager layout) {
    super(layout);
  }

  public JBPanel(boolean isDoubleBuffered) {
    super(isDoubleBuffered);
  }

  public JBPanel() {
    super();
  }

  @Nullable
  public Icon getBackgroundImage() {
    return myBackgroundImage;
  }

  public void setBackgroundImage(@Nullable Icon backgroundImage) {
    myBackgroundImage = backgroundImage;
  }

  @Nullable
  public Icon getCenterImage() {
    return myCenterImage;
  }

  public void setCenterImage(@Nullable Icon centerImage) {
    myCenterImage = centerImage;
  }

  @Override
  protected void paintComponent(Graphics g) {
    Icon image = getBackgroundImage();
    if (image != null) {
      final int w = image.getIconWidth();
      final int h = image.getIconHeight();
      int x = 0;
      int y = 0;
      while (w > 0 &&  x < getWidth()) {
        while (h > 0 && y < getHeight()) {
          image.paintIcon(this, g, x, y);
          y+=h;
        }
        y=0;
        x+=w;
      }
    } else {
      super.paintComponent(g);
    }

    paintCenterImage(g);
  }

  protected void paintCenterImage(Graphics g) {
    Icon centerImage = getCenterImage();
    if (centerImage != null) {
      IconUtil.paintInCenterOf(this, g, centerImage);
    }
  }

  @Override
  public void calcData(DataKey key, DataSink sink) {
    // override this to provide additional context
  }
}

==> ideaIC-143.747.6-sources.jar: com/intellij/ui/components/JBPanel.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.ui.components;

import com.intellij.util.ui.JBFont;
import com.intellij.util.ui.components.JBComponent;

import javax.swing.*;
import javax.swing.border.Border;
import java.awt.*;

/**
 * @author Konstantin Bulenkov
 */
@SuppressWarnings("unchecked")
public class JBPanel<T extends JBPanel> extends JPanel implements JBComponent<T> {

  public JBPanel(LayoutManager layout, boolean isDoubleBuffered) {
    super(layout, isDoubleBuffered);
  }

  public JBPanel(LayoutManager layout) {
    super(layout);
  }

  public JBPanel(boolean isDoubleBuffered) {
    super(isDoubleBuffered);
  }

  public JBPanel() {
    super();
  }

  @Override
  public T withBorder(Border border) {
    setBorder(border);
    return (T)this;
  }

  @Override
  public T withFont(JBFont font) {
    setFont(font);
    return (T)this;
  }

  @Override
  public T andTransparent() {
    setOpaque(false);
    return (T)this;
  }

  @Override
  public T andOpaque() {
    setOpaque(true);
    return (T)this;
  }
}
